@@ -1,5 +1,5 @@
 test_that("pdo_download", {
-  rlang::scoped_options(lifecycle_verbosity = "quiet")
+  rlang::local_options(lifecycle_verbosity = "quiet")
 
   expect_is(download_pdo(), "data.frame")
   expect_is(pdo_download(), "data.frame")
